<script setup name="devNormal">
import { ref, reactive, onMounted, computed, onActivated } from "vue";
import devCard from "./devCard.vue";
import addEdit from "./addEdit.vue";
import { useRoute, useRouter } from "vue-router";
import useWebSocket from "@/hooks/useWebSocket";
const { sendData, message: message1 } = useWebSocket("dinfSocket");

const $route = useRoute();
const $router = useRouter();

const pageCurr = ref(1);
const pageSize = ref(10);
const dialogTitle = ref("");
const addEditVisible = ref(false);
const devInfo = ref();

const devType = ref(1);

function onOk() {
  addEditVisible.value = false;
  handleCurrentChange(1);
}
function onCanel() {
  addEditVisible.value = false;
}

function add() {
  dialogTitle.value = "添加设备";
  addEditVisible.value = true;
}

const rtdata = computed(() => {
  if (message1.value) {
    const {
      code,
      data2: {
        onlineMap,
        pageInfo: { list, total },
        type,
        devSum,
      },
    } = JSON.parse(message1.value);

    return { onlineMap, list, total, type, devSum };
  } else {
    let onlineMap = {},
      list = [],
      total = 0,
      type = {},
      devSum = 0;
    return { onlineMap, list, total, type, devSum };
  }
});
function sendMessage() {
  sendData(
    JSON.stringify({
      pageNum: pageCurr.value,
      pageSize: pageSize.value,
      devType: devType.value,
    })
  );
}
function handleSizeChange(val) {
  pageSize.value = val;
  sendMessage();
}
// 翻页
function handleCurrentChange(val) {
  pageCurr.value = val;
  sendMessage();
}

function toggle() {
  // 跳转到list页面  带页码信息
  $router.push({
    path: "/dev/list",
    query: {
      pageCurr: pageCurr.value,
      pageSize: pageSize.value,
      devType: devType.value,
    },
  });
}

onMounted(() => {
  let { query } = $route;
  if (query.pageCurr) {
    pageCurr.value = query.pageCurr * 1;
    pageSize.value = query.pageSize * 1;
    devType.value = query.devType * 1;
  }
  // console.log('active', $route, '=============');
  sendMessage();
});
onActivated(() => {
  let { query } = $route;
  if (query.pageCurr) {
    pageCurr.value = query.pageCurr * 1;
    pageSize.value = query.pageSize * 1;
    devType.value = query.devType * 1;
  }
  // console.log('active', $route, '=============');
  sendMessage();
});
</script>

<template>
  <!-- 设备视图 -->
  <div class="page">
    <div class="p-header">
      <div class="info">
        <div class="item">
          <div class="label">全部设备</div>
          <div class="value">{{ rtdata.devSum }}</div>
        </div>
        <div class="item">
          <div class="label">充放电测试仪</div>
          <div class="value">{{ rtdata.type[1] }}</div>
        </div>
        <div class="item">
          <div class="label">锂电池均衡维护仪</div>
          <div class="value">{{ rtdata.type[2] }}</div>
        </div>
        <div class="item">
          <div class="label">在线</div>
          <div class="value">{{ rtdata.onlineMap[1] }}</div>
        </div>
        <div class="item">
          <div class="label">离线</div>
          <div class="value">{{ rtdata.onlineMap[0] }}</div>
        </div>
      </div>
      <!-- 切换按钮 -->
      <div class="btn-change-type" @click="toggle" title="跳转到列表页"></div>
    </div>
    <div class="p-content">
      <div class="tabs">
        <el-radio-group
          v-model="devType"
          @change="sendMessage"
          size="default"
          is-button
        >
          <el-radio-button :value="1">充放电测试仪</el-radio-button>
          <el-radio-button :value="2">均衡测试仪</el-radio-button>
        </el-radio-group>
      </div>
      <div class="list posR">
        <div class="pos-full">
          <div class="list-scroller">
            <dev-card class="add-dev" @click="add"></dev-card>
            <dev-card
              v-for="dev in rtdata.list"
              :key="dev.devId"
              :devIdcode="dev.devIdcode"
              :onLine="!!dev.devOnline"
              :devType="dev.devType"
            ></dev-card>
          </div>
        </div>
      </div>
    </div>
    <div class="p-footer">
      <!-- 底部分页 -->
      <el-pagination
        class="yc-pagination"
        :current-page="pageCurr"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :page-sizes="[10, 20, 30, 50, 100]"
        :page-size="pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="rtdata.total"
      ></el-pagination>
    </div>
    <!-- 弹窗 -->
    <el-dialog
      :title="dialogTitle"
      v-model="addEditVisible"
      top="0"
      :close-on-click-modal="false"
      class="dialog-center"
      width="580px"
      center
    >
      <add-edit
        v-if="addEditVisible"
        @success="onOk"
        :info="devInfo"
        @cancel="onCanel"
      ></add-edit>
    </el-dialog>
  </div>
</template>

<style scoped lang="less">
.add-dev {
  cursor: pointer;
}
.page {
  height: 100%;
  display: flex;
  flex-direction: column;
  .p-header {
    display: flex;
    justify-content: space-between;
    padding: 0 10px;
    .info {
      display: flex;
      font-size: 14px;
      align-items: center;
      .item {
        display: flex;
        & ~ .item {
          margin-left: 2em;
        }
      }
      .label {
        color: #0ff;
        margin-right: 0.6em;
        &::after {
          content: ":";
        }
      }
      .value {
        color: #fff;
        font-weight: bold;
      }
    }
    .btn-change-type {
      cursor: pointer;
      background: url('data:image/svg+xml,%3csvg viewBox="0 0 1024 1024" xmlns="http://www.w3.org/2000/svg" fill="%23ffffff"%3e%3cpath d="M335.580988 330.511529c0 10.737552-8.705266 19.442818-19.442818 19.442818l-99.253538 0c-10.737552 0-19.442818-8.705266-19.442818-19.442818l0-45.579081c0-10.737552 8.705266-19.442818 19.442818-19.442818l99.253538 0c10.737552 0 19.442818 8.705266 19.442818 19.442818L335.580988 330.511529z" /%3e%3cpath d="M851.301729 330.511529c0 10.737552-8.705266 19.442818-19.442818 19.442818L421.023986 349.954347c-10.737552 0-19.442818-8.705266-19.442818-19.442818l0-45.579081c0-10.737552 8.705266-19.442818 19.442818-19.442818l410.834926 0c10.737552 0 19.442818 8.705266 19.442818 19.442818L851.301729 330.511529 851.301729 330.511529z" /%3e%3cpath d="M335.580988 518.139837c0 10.737552-8.705266 19.442818-19.442818 19.442818l-99.253538 0c-10.737552 0-19.442818-8.705266-19.442818-19.442818l0-45.579081c0-10.737552 8.705266-19.442818 19.442818-19.442818l99.253538 0c10.737552 0 19.442818 8.705266 19.442818 19.442818L335.580988 518.139837z" /%3e%3cpath d="M851.301729 518.139837c0 10.737552-8.705266 19.442818-19.442818 19.442818L421.023986 537.582655c-10.737552 0-19.442818-8.705266-19.442818-19.442818l0-45.579081c0-10.737552 8.705266-19.442818 19.442818-19.442818l410.834926 0c10.737552 0 19.442818 8.705266 19.442818 19.442818L851.301729 518.139837 851.301729 518.139837z" /%3e%3cpath d="M335.580988 700.288341c0 10.737552-8.705266 19.442818-19.442818 19.442818l-99.253538 0c-10.737552 0-19.442818-8.705266-19.442818-19.442818l0-45.579081c0-10.737552 8.705266-19.442818 19.442818-19.442818l99.253538 0c10.737552 0 19.442818 8.705266 19.442818 19.442818L335.580988 700.288341z" /%3e%3cpath d="M851.301729 700.288341c0 10.737552-8.705266 19.442818-19.442818 19.442818L421.023986 719.731158c-10.737552 0-19.442818-8.705266-19.442818-19.442818l0-45.579081c0-10.737552 8.705266-19.442818 19.442818-19.442818l410.834926 0c10.737552 0 19.442818 8.705266 19.442818 19.442818L851.301729 700.288341 851.301729 700.288341z" /%3e%3c/svg%3e');
      width: 30px;
      height: 30px;
    }
  }
  .p-content {
    flex: 1;
    display: flex;
    flex-direction: column;
    .tabs {
      // padding: 0 6em;
      display: flex;
      justify-content: center;
    }
    .list {
      margin: 10px 0;
      flex: 1;
      .list-scroller {
        height: 100%;
        min-height: 0;
        display: grid;
        grid-template-columns: repeat(auto-fill, 230px);
        overflow-y: auto;
        gap: 24px;
        // justify-content: center;
        place-content: start center;
      }
    }
  }
  .p-footer {
    padding: 6px;
  }
}
</style>
